#!/bin/tcsh

#
# This example script uses the command-line JsonGenerator to make 
# a sample set Cosmographia JSON catalog files for  
# an observation by the CASSINI ISS NAC camera. 
#

#
# First, let's do some prep work: make output directories and 
# observation CSV files.
#
set DESTDIR = `pwd`"/CASSINI"

mkdir -p $DESTDIR $DESTDIR/sensors $DESTDIR/observations

set OUTFILE = $DESTDIR/timelist.csv
echo "2004-05-24 05:48:03.043,2004-05-24 05:48:08.643,0"  > $OUTFILE
echo "2004-05-24 05:48:59.650,2004-05-24 05:49:21.650,0" >> $OUTFILE
echo "2004-05-24 05:51:07.661,2004-05-24 05:51:29.661,0" >> $OUTFILE
echo "2004-05-24 05:53:03.069,2004-05-24 05:53:05.669,0" >> $OUTFILE

set OUTFILE = $DESTDIR/timelist_titan.csv
echo "2005-03-31 19:48:03.043,2005-03-31 19:48:08.643,0"  > $OUTFILE
echo "2005-03-31 19:48:59.650,2005-03-31 19:49:21.650,0" >> $OUTFILE
echo "2005-03-31 19:51:07.661,2005-03-31 19:51:29.661,0" >> $OUTFILE
echo "2005-03-31 19:53:03.069,2005-03-31 19:53:05.669,0" >> $OUTFILE

#
# Now, run JsonGenerator (assuming that it's located under ../bin)
# to generate s/c, sensor, observation, spice data and load catalogs.
# Note that -gencraft's -mp and -genspice's -kr options refer to the
# 3D model and SPICE meta-kernel files not included with or generated 
# by this example script.
#
java -jar ../bin/JsonGenerator.jar \
\
-genglobe \
-of $DESTDIR/Saturn.json \
-mn Cassini \
-ty planet \
-ms 95.152 \
-ds 0.687 \
-cn Saturn \
-bs 1900-01-01 00:00:00.000 \
-be 2100-01-01 00:00:00.000 \
-cc Sun \
-sc Sun \
-st Saturn \
-bf IAU_SATURN \
-rd 60268 60268 54364 \
-mp textures/saturn.jpg \
-lc 1 0.5 1 \
-tc 1 0.5 1 \
-dr 29 \
-fd 0.1 \
\
-gencraft \
-of $DESTDIR/Cassini.json \
-mn Cassini_Example \
-cn Cassini \
-bs 1997-10-15 09:26:08.390 2004-07-04 02:48:00.000 \
-be 2004-07-04 02:48:00.000 2015-08-01 01:58:52.000 \
-cc Sun                     Saturn \
-sc Sun                     Saturn \
-st Cassini \
-bf CASSINI_SC_COORD \
-mr 0 0 -0.70710677 0.70710677 \
-sz 0.005 \
-mp models/cassini/Cassini_no_Huygens_03.3ds \
-lc 0.6 1 1 \
-tc 0.6 1 1 \
-dr 0.04 \
-fd 0.5 \
\
-gencraft \
-of $DESTDIR/Cassini_No_Arcs.json \
-mn Cassini_Example \
-cn Cassini_No_Arcs \
-bs 2004-07-04 02:48:00.000 \
-be 2015-08-01 01:58:52.000 \
-cc Saturn \
-sc Saturn \
-st Cassini \
-bf CASSINI_SC_COORD \
-mr 0 0 -0.70710677 0.70710677 \
-sz 0.005 \
-mp models/cassini/Cassini_no_Huygens_03.3ds \
-lc 0.6 0 1 \
-tc 0.6 0 1 \
-dr 0.04 \
-fd 0.5 \
\
-geninst \
-of $DESTDIR/CAS_ISS_NAC.json \
-sn CAS_ISS_NAC\
-si CASSINI_ISS_NAC \
-ct Saturn \
-rg 45000 \
-rt \
-fc 0 1 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 3000 \
-sp $DESTDIR/Cassini.json \
\
-geninst \
-of $DESTDIR/CAS_ISS_NAC_TITAN.json \
-sn CAS_ISS_NAC_TITAN \
-si CASSINI_ISS_NAC \
-ct Titan \
-rg 45000 \
-rt \
-fc 1 0 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 3000 \
-sp $DESTDIR/Cassini.json \
\
-genobs \
-of $DESTDIR/CASSINI_ISS_NAC_OBSERVATION.json \
-on CASSINI_ISS_NAC_OBSERVATION \
-op 0.5 \
-td 10 \
-pc 0.5 0.5 1 \
-sv 1.75 \
-ip $DESTDIR/CAS_ISS_NAC.json \
-tp $DESTDIR/timelist.csv \
\
-genobs \
-of $DESTDIR/CASSINI_ISS_NAC_TITAN_050331.json \
-on CASSINI_ISS_NAC_TITAN_050331 \
-op 0.5 \
-td 10 \
-pc 0.5 0.5 1 \
-sv 1.75 \
-ip $DESTDIR/CAS_ISS_NAC_TITAN.json \
-tp $DESTDIR/timelist_titan.csv \
\
-genspice \
-of $DESTDIR/spiceKernels.json \
-kr \
cas_1997_v15.tm \
cas_1998_v15.tm \
cas_1999_v15.tm \
cas_2000_v17.tm \
cas_2001_v18.tm \
cas_2002_v17.tm \
cas_2003_v17.tm \
cas_2004_v17.tm \
cas_2005_v18.tm \
cas_2006_v17.tm \
cas_2007_v15.tm \
cas_2008_v13.tm \
cas_2009_v10.tm \
cas_2010_v09.tm \
cas_2011_v08.tm \
cas_2012_v05.tm \
cas_2013_v02.tm \
-kp kernels \
\
-genload \
-of $DESTDIR/load_SATURN_OBS.json \
-ln \
spiceKernels.json \
Cassini.json \
CAS_ISS_NAC.json \
CASSINI_ISS_NAC_OBSERVATION.json \
\
-genload \
-of $DESTDIR/load_TITAN_OBS.json \
-ln \
spiceKernels.json \
Cassini.json \
CAS_ISS_NAC_TITAN.json \
CASSINI_ISS_NAC_TITAN_050331.json



exit;
