#!/bin/tcsh

#
# This example script uses the command-line JsonGenerator to make 
# a fairly complete sample set Cosmographia JSON catalog files for  
# the MESSENGER mission. 
#

#
# First, let's do some prep work: make output directories and 
# observation CSV files.
#
set DESTDIR = `pwd`"/MESS"

mkdir -p $DESTDIR $DESTDIR/sensors $DESTDIR/observations

set OUTFILE = $DESTDIR/timelist_MSGR_MASCS_UVVS.csv
echo "2014-02-09 01:25:00,2014-02-09 01:25:10,0"          > $OUTFILE
echo "2014-02-09 01:27:51,2014-02-09 01:28:01,0"         >> $OUTFILE

set OUTFILE = $DESTDIR/timelist_MSGR_MASCS_VIRS.csv
echo "2014-02-09 00:38:54,2014-02-09 01:06:16,0"          > $OUTFILE
echo "2014-02-09 01:06:41,2014-02-09 01:23:18,0"         >> $OUTFILE
echo "2014-02-09 01:24:25,2014-02-09 01:24:57,0"         >> $OUTFILE
echo "2014-02-09 01:27:16,2014-02-09 01:27:48,0"         >> $OUTFILE

set OUTFILE = $DESTDIR/timelist_MSGR_MDIS_NAC.csv
echo "2014-02-09 01:58:00.795,2014-02-09 01:58:00.796,0"  > $OUTFILE
echo "2014-02-09 01:58:02.795,2014-02-09 01:58:02.796,0" >> $OUTFILE
echo "2014-02-09 01:58:04.795,2014-02-09 01:58:04.796,0" >> $OUTFILE
echo "2014-02-09 01:58:06.795,2014-02-09 01:58:06.796,0" >> $OUTFILE
echo "2014-02-09 01:58:08.795,2014-02-09 01:58:08.796,0" >> $OUTFILE
echo "2014-02-09 01:58:10.795,2014-02-09 01:58:10.796,0" >> $OUTFILE

set OUTFILE = $DESTDIR/timelist_MSGR_MDIS_WAC.csv
echo "2014-02-09 01:35:30.760,2014-02-09 01:35:30.780,0"  > $OUTFILE

set OUTFILE = $DESTDIR/timelist_MSGR_MLA.csv
echo "2014-02-09 01:43:45,2014-02-09 02:12:39,0"          > $OUTFILE

set OUTFILE = $DESTDIR/timelist_MSGR_XRS.csv
echo "2014-02-09 01:00:00,2014-02-09 01:30:00,60"          > $OUTFILE

#
# Now, run JsonGenerator (assuming that it's located under ../bin)
# to generate s/c, sensor, observation, spice data and load catalogs.
# Note that -gencraft's -mp and -genspice's -kr options refer to the
# 3D model and SPICE meta-kernel files not included with or generated 
# by this example script.
#
java -jar ../bin/JsonGenerator.jar \
\
-gencraft \
-of $DESTDIR/spacecraft_MSGR.json \
-mn 'MESSENGER example' \
-cn MESSENGER \
-bs 2004-08-03 07:13:14.000 2011-03-18 01:00:00.000 \
-be 2011-03-18 01:00:00.000 2015-04-30 19:26:00.000 \
-cc Sun                     Mercury \
-sc Sun                     Mercury \
-st MESSENGER \
-bf MSGR_SPACECRAFT \
-mr 0.00000000 0.70710678 -0.70710678 0.0 \
-sz 0.004 \
-mp models/MESSENGER.3ds \
-lc 0.6 1 1 \
-tc 0.6 1 1 \
-dr 0.5 \
-fd 0.6 \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_MDIS_NAC-MERCURY.json \
-sn MSGR_MDIS_NAC \
-si MSGR_MDIS_NAC \
-ct Mercury \
-rg 500 \
-rt \
-fc 1 0 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-vo \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-genobs \
-of $DESTDIR/observations/obs_MSGR_MDIS_NAC-MERCURY-140209.json \
-on MSGR_MDIS_NAC_OBS \
-op 0.5 \
-td 10 \
-pc 1 0 1 \
-sv 1.75 \
-ip $DESTDIR/sensors/sensor_MSGR_MDIS_NAC-MERCURY.json \
-tp $DESTDIR/timelist_MSGR_MDIS_NAC.csv \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_MDIS_WAC-MERCURY.json \
-sn MSGR_MDIS_WAC \
-si MSGR_MDIS_WAC \
-ct Mercury \
-rg 500 \
-rt \
-fc 0 1 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-vo \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-genobs \
-of $DESTDIR/observations/obs_MSGR_MDIS_WAC-MERCURY-140209.json \
-on MSGR_MDIS_WAC_OBS \
-op 0.5 \
-td 10 \
-pc 0 1 1 \
-sv 1.75 \
-ip $DESTDIR/sensors/sensor_MSGR_MDIS_WAC-MERCURY.json \
-tp $DESTDIR/timelist_MSGR_MDIS_WAC.csv \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_MLA-MERCURY.json \
-sn MSGR_MLA \
-si MSGR_MLA \
-ct Mercury \
-rg 500 \
-rt \
-fc 1 1 0 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-genobs \
-of $DESTDIR/observations/obs_MSGR_MLA-MERCURY-140209.json \
-on MSGR_MLA_OBS \
-op 0.5 \
-td 1000 \
-pc 1 1 0 \
-sv 1.75 \
-ip $DESTDIR/sensors/sensor_MSGR_MLA-MERCURY.json \
-tp $DESTDIR/timelist_MSGR_MLA.csv \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_MLA_RECEIVER-MERCURY.json \
-sn MSGR_MLA_RECEIVER \
-si MSGR_MLA_RECEIVER \
-ct Mercury \
-rg 500 \
-rt \
-fc 1 0 0 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-genobs \
-of $DESTDIR/observations/obs_MSGR_MLA_RECEIVER-MERCURY-140209.json \
-on MSGR_MLA_RECEIVER_OBS \
-op 0.5 \
-td 1000 \
-pc 1 0 0 \
-sv 1.75 \
-ip $DESTDIR/sensors/sensor_MSGR_MLA_RECEIVER-MERCURY.json \
-tp $DESTDIR/timelist_MSGR_MLA.csv \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_MASCS_UVVS_ATMO-MERCURY.json \
-sn MSGR_MASCS_UVVS_ATMO \
-si MSGR_MASCS_UVVS_ATMO \
-ct Mercury \
-rg 500 \
-rt \
-fc 1 0.5 0.1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-genobs \
-of $DESTDIR/observations/obs_MSGR_MASCS_UVVS_ATMO-MERCURY-140209.json \
-on MSGR_MASCS_UVVS_ATMO_OBS \
-op 0.5 \
-td 10 \
-pc 1 0.5 0.1 \
-sv 1.75 \
-ip $DESTDIR/sensors/sensor_MSGR_MASCS_UVVS_ATMO-MERCURY.json \
-tp $DESTDIR/timelist_MSGR_MASCS_UVVS.csv \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_MASCS_UVVS_SURF-MERCURY.json \
-sn MSGR_MASCS_UVVS_SURF \
-si MSGR_MASCS_UVVS_SURF \
-ct Mercury \
-rg 500 \
-rt \
-fc 1 0.5 0.2 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-genobs \
-of $DESTDIR/observations/obs_MSGR_MASCS_UVVS_SURF-MERCURY-140209.json \
-on MSGR_MASCS_UVVS_SURF_OBS \
-op 0.5 \
-td 10 \
-pc 1 0.5 0.2 \
-sv 1.75 \
-ip $DESTDIR/sensors/sensor_MSGR_MASCS_UVVS_SURF-MERCURY.json \
-tp $DESTDIR/timelist_MSGR_MASCS_UVVS.csv \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_MASCS_VIRS-MERCURY.json \
-sn MSGR_MASCS_VIRS \
-si MSGR_MASCS_VIRS \
-ct Mercury \
-rg 500 \
-rt \
-fc 1 0.5 0.3 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-genobs \
-of $DESTDIR/observations/obs_MSGR_MASCS_VIRS-MERCURY-140209.json \
-on MSGR_MASCS_VIRS_OBS \
-op 0.5 \
-td 10 \
-pc 1 0.5 0.3 \
-sv 1.75 \
-ip $DESTDIR/sensors/sensor_MSGR_MASCS_VIRS-MERCURY.json \
-tp $DESTDIR/timelist_MSGR_MASCS_VIRS.csv \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_XRS_MXU-MERCURY.json \
-sn MSGR_XRS_MXU \
-si MSGR_XRS_MXU \
-ct Mercury \
-rg 500 \
-rt \
-fc 0 0.4 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-genobs \
-of $DESTDIR/observations/obs_MSGR_XRS_MXU-MERCURY-140209.json \
-on MSGR_XRS_MXU_OBS \
-op 0.5 \
-td 10 \
-pc 0 0.4 1 \
-sv 1.75 \
-ip $DESTDIR/sensors/sensor_MSGR_XRS_MXU-MERCURY.json \
-tp $DESTDIR/timelist_MSGR_XRS.csv \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_XRS_SAX-MERCURY.json \
-sn MSGR_XRS_SAX \
-si MSGR_XRS_SAX \
-ct Mercury \
-rg 5 \
-fc 0 0.6 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-genobs \
-of $DESTDIR/observations/obs_MSGR_XRS_SAX-MERCURY-140209.json \
-on MSGR_XRS_SAX_OBS \
-op 0.5 \
-td 10 \
-pc 0 0.6 1 \
-sv 1.75 \
-ip $DESTDIR/sensors/sensor_MSGR_XRS_SAX-MERCURY.json \
-tp $DESTDIR/timelist_MSGR_XRS.csv \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_EPS_SSD0.json \
-sn MSGR_EPPS_EPS_SSD0 \
-si MSGR_EPPS_EPS_SSD0 \
-ct Mercury \
-rg 5 \
-fc 0.5 0 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_EPS_SSD1.json \
-sn MSGR_EPPS_EPS_SSD1 \
-si MSGR_EPPS_EPS_SSD1 \
-ct Mercury \
-rg 5 \
-fc 0.5 0 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_EPS_SSD2.json \
-sn MSGR_EPPS_EPS_SSD2 \
-si MSGR_EPPS_EPS_SSD2 \
-ct Mercury \
-rg 5 \
-fc 0.5 0 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_EPS_SSD3.json \
-sn MSGR_EPPS_EPS_SSD3 \
-si MSGR_EPPS_EPS_SSD3 \
-ct Mercury \
-rg 5 \
-fc 0.5 0 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_EPS_SSD4.json \
-sn MSGR_EPPS_EPS_SSD4 \
-si MSGR_EPPS_EPS_SSD4 \
-ct Mercury \
-rg 5 \
-fc 0.5 0 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_EPS_SSD5.json \
-sn MSGR_EPPS_EPS_SSD5 \
-si MSGR_EPPS_EPS_SSD5 \
-ct Mercury \
-rg 5 \
-fc 0.5 0 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_EPS_SSD6.json \
-sn MSGR_EPPS_EPS_SSD6 \
-si MSGR_EPPS_EPS_SSD6 \
-ct Mercury \
-rg 5 \
-fc 0.5 0 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_EPS_SSD7.json \
-sn MSGR_EPPS_EPS_SSD7 \
-si MSGR_EPPS_EPS_SSD7 \
-ct Mercury \
-rg 5 \
-fc 0.5 0 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_EPS_SSD8.json \
-sn MSGR_EPPS_EPS_SSD8 \
-si MSGR_EPPS_EPS_SSD8 \
-ct Mercury \
-rg 5 \
-fc 0.5 0 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_EPS_SSD9.json \
-sn MSGR_EPPS_EPS_SSD9 \
-si MSGR_EPPS_EPS_SSD9 \
-ct Mercury \
-rg 5 \
-fc 0.5 0 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_EPS_SSD10.json \
-sn MSGR_EPPS_EPS_SSD10 \
-si MSGR_EPPS_EPS_SSD10 \
-ct Mercury \
-rg 5 \
-fc 0.5 0 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_EPS_SSD11.json \
-sn MSGR_EPPS_EPS_SSD11 \
-si MSGR_EPPS_EPS_SSD11 \
-ct Mercury \
-rg 5 \
-fc 0.5 0 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR1.json \
-sn MSGR_EPPS_FIPS_SECTOR1 \
-si MSGR_EPPS_FIPS_SECTOR1 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR2.json \
-sn MSGR_EPPS_FIPS_SECTOR2 \
-si MSGR_EPPS_FIPS_SECTOR2 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR3.json \
-sn MSGR_EPPS_FIPS_SECTOR3 \
-si MSGR_EPPS_FIPS_SECTOR3 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR4.json \
-sn MSGR_EPPS_FIPS_SECTOR4 \
-si MSGR_EPPS_FIPS_SECTOR4 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR5.json \
-sn MSGR_EPPS_FIPS_SECTOR5 \
-si MSGR_EPPS_FIPS_SECTOR5 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR6.json \
-sn MSGR_EPPS_FIPS_SECTOR6 \
-si MSGR_EPPS_FIPS_SECTOR6 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR7.json \
-sn MSGR_EPPS_FIPS_SECTOR7 \
-si MSGR_EPPS_FIPS_SECTOR7 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR8.json \
-sn MSGR_EPPS_FIPS_SECTOR8 \
-si MSGR_EPPS_FIPS_SECTOR8 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR9.json \
-sn MSGR_EPPS_FIPS_SECTOR9 \
-si MSGR_EPPS_FIPS_SECTOR9 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR10.json \
-sn MSGR_EPPS_FIPS_SECTOR10 \
-si MSGR_EPPS_FIPS_SECTOR10 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR11.json \
-sn MSGR_EPPS_FIPS_SECTOR11 \
-si MSGR_EPPS_FIPS_SECTOR11 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR12.json \
-sn MSGR_EPPS_FIPS_SECTOR12 \
-si MSGR_EPPS_FIPS_SECTOR12 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR13.json \
-sn MSGR_EPPS_FIPS_SECTOR13 \
-si MSGR_EPPS_FIPS_SECTOR13 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR14.json \
-sn MSGR_EPPS_FIPS_SECTOR14 \
-si MSGR_EPPS_FIPS_SECTOR14 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR15.json \
-sn MSGR_EPPS_FIPS_SECTOR15 \
-si MSGR_EPPS_FIPS_SECTOR15 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR16.json \
-sn MSGR_EPPS_FIPS_SECTOR16 \
-si MSGR_EPPS_FIPS_SECTOR16 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR17.json \
-sn MSGR_EPPS_FIPS_SECTOR17 \
-si MSGR_EPPS_FIPS_SECTOR17 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR18.json \
-sn MSGR_EPPS_FIPS_SECTOR18 \
-si MSGR_EPPS_FIPS_SECTOR18 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR19.json \
-sn MSGR_EPPS_FIPS_SECTOR19 \
-si MSGR_EPPS_FIPS_SECTOR19 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR20.json \
-sn MSGR_EPPS_FIPS_SECTOR20 \
-si MSGR_EPPS_FIPS_SECTOR20 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR21.json \
-sn MSGR_EPPS_FIPS_SECTOR21 \
-si MSGR_EPPS_FIPS_SECTOR21 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR22.json \
-sn MSGR_EPPS_FIPS_SECTOR22 \
-si MSGR_EPPS_FIPS_SECTOR22 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR23.json \
-sn MSGR_EPPS_FIPS_SECTOR23 \
-si MSGR_EPPS_FIPS_SECTOR23 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_EPPS_FIPS_SECTOR24.json \
-sn MSGR_EPPS_FIPS_SECTOR24 \
-si MSGR_EPPS_FIPS_SECTOR24 \
-ct Mercury \
-rg 5 \
-fc 0.5 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_RS_PAA_FRONT.json \
-sn MSGR_RS_PAA_FRONT \
-si MSGR_RS_PAA_FRONT \
-ct Mercury \
-rg 5 \
-fc 0 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_RS_PAA_REAR.json \
-sn MSGR_RS_PAA_REAR \
-si MSGR_RS_PAA_REAR \
-ct Mercury \
-rg 5 \
-fc 0 0.5 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_RS_FB_FRONT.json \
-sn MSGR_RS_FB_FRONT \
-si MSGR_RS_FB_FRONT \
-ct Mercury \
-rg 5 \
-fc 0 0.8 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-geninst \
-of $DESTDIR/sensors/sensor_MSGR_RS_FB_REAR.json \
-sn MSGR_RS_FB_REAR \
-si MSGR_RS_FB_REAR \
-ct Mercury \
-rg 5 \
-fc 0 0.8 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_MSGR.json \
\
-genspice \
-of $DESTDIR/spice_MSGR.json \
-kr \
msgr_2004_v12.tm \
msgr_2005_v12.tm \
msgr_2006_v12.tm \
msgr_2007_v01.tm \
msgr_2008_v11.tm \
msgr_2009_v09.tm \
msgr_2010_v08.tm \
msgr_2011_v09.tm \
msgr_2012_v07.tm \
msgr_2013_v05.tm \
msgr_2014_v03.tm \
msgr_2015_v01.tm \
-kp kernels \
\
-genspice \
-of $DESTDIR/spice_MSGR_1402.json \
-kr msgr_2014_v03_140201_140301.tm \
-kp kernels \
\
-genload \
-of $DESTDIR/load_sensor_MSGR_EPPS_EPS.json \
-ln \
sensors/sensor_MSGR_EPPS_EPS_SSD0.json \
sensors/sensor_MSGR_EPPS_EPS_SSD1.json \
sensors/sensor_MSGR_EPPS_EPS_SSD2.json \
sensors/sensor_MSGR_EPPS_EPS_SSD3.json \
sensors/sensor_MSGR_EPPS_EPS_SSD4.json \
sensors/sensor_MSGR_EPPS_EPS_SSD5.json \
sensors/sensor_MSGR_EPPS_EPS_SSD6.json \
sensors/sensor_MSGR_EPPS_EPS_SSD7.json \
sensors/sensor_MSGR_EPPS_EPS_SSD8.json \
sensors/sensor_MSGR_EPPS_EPS_SSD9.json \
sensors/sensor_MSGR_EPPS_EPS_SSD10.json \
sensors/sensor_MSGR_EPPS_EPS_SSD11.json \
\
-genload \
-of $DESTDIR/load_sensor_MSGR_EPPS_FIPS.json \
-ln \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR1.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR2.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR3.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR4.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR5.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR6.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR7.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR8.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR9.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR10.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR11.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR12.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR13.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR14.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR15.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR16.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR17.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR18.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR19.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR20.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR21.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR22.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR23.json \
sensors/sensor_MSGR_EPPS_FIPS_SECTOR24.json \
\
-genload \
-of $DESTDIR/load_sensor_MSGR_RS.json \
-ln \
sensors/sensor_MSGR_RS_PAA_FRONT.json \
sensors/sensor_MSGR_RS_PAA_REAR.json \
sensors/sensor_MSGR_RS_FB_FRONT.json \
sensors/sensor_MSGR_RS_FB_REAR.json \
\
-genload \
-of $DESTDIR/load_sensor_MSGR_MDIS.json \
-ln \
sensors/sensor_MSGR_MDIS_NAC-MERCURY.json \
sensors/sensor_MSGR_MDIS_WAC-MERCURY.json \
\
-genload \
-of $DESTDIR/load_sensor_MSGR_MLA.json \
-ln \
sensors/sensor_MSGR_MLA-MERCURY.json \
sensors/sensor_MSGR_MLA_RECEIVER-MERCURY.json \
\
-genload \
-of $DESTDIR/load_sensor_MSGR_MASCS.json \
-ln \
sensors/sensor_MSGR_MASCS_UVVS_ATMO-MERCURY.json \
sensors/sensor_MSGR_MASCS_UVVS_SURF-MERCURY.json \
sensors/sensor_MSGR_MASCS_VIRS-MERCURY.json \
\
-genload \
-of $DESTDIR/load_MSGR.json \
-ln \
spice_MSGR.json \
spacecraft_MSGR.json \
sensors/sensor_MSGR_MDIS_NAC-MERCURY.json \
sensors/sensor_MSGR_MDIS_WAC-MERCURY.json \
sensors/sensor_MSGR_MLA-MERCURY.json \
sensors/sensor_MSGR_MLA_RECEIVER-MERCURY.json \
sensors/sensor_MSGR_MASCS_UVVS_ATMO-MERCURY.json \
sensors/sensor_MSGR_MASCS_UVVS_SURF-MERCURY.json \
sensors/sensor_MSGR_MASCS_VIRS-MERCURY.json \
sensors/sensor_MSGR_XRS_MXU-MERCURY.json \
observations/obs_MSGR_MDIS_NAC-MERCURY-140209.json \
observations/obs_MSGR_MDIS_WAC-MERCURY-140209.json \
observations/obs_MSGR_MLA-MERCURY-140209.json \
observations/obs_MSGR_MLA_RECEIVER-MERCURY-140209.json \
observations/obs_MSGR_MASCS_UVVS_ATMO-MERCURY-140209.json \
observations/obs_MSGR_MASCS_UVVS_SURF-MERCURY-140209.json \
observations/obs_MSGR_MASCS_VIRS-MERCURY-140209.json \
observations/obs_MSGR_XRS_MXU-MERCURY-140209.json \
\
-genload \
-of $DESTDIR/load_MSGR_1402.json \
-ln \
spice_MSGR_1402.json \
spacecraft_MSGR.json \
sensors/sensor_MSGR_MDIS_NAC-MERCURY.json \
sensors/sensor_MSGR_MDIS_WAC-MERCURY.json \
sensors/sensor_MSGR_MLA-MERCURY.json \
sensors/sensor_MSGR_MLA_RECEIVER-MERCURY.json \
sensors/sensor_MSGR_MASCS_UVVS_ATMO-MERCURY.json \
sensors/sensor_MSGR_MASCS_UVVS_SURF-MERCURY.json \
sensors/sensor_MSGR_MASCS_VIRS-MERCURY.json \
sensors/sensor_MSGR_XRS_MXU-MERCURY.json \
observations/obs_MSGR_MDIS_NAC-MERCURY-140209.json \
observations/obs_MSGR_MDIS_WAC-MERCURY-140209.json \
observations/obs_MSGR_MLA-MERCURY-140209.json \
observations/obs_MSGR_MLA_RECEIVER-MERCURY-140209.json \
observations/obs_MSGR_MASCS_UVVS_ATMO-MERCURY-140209.json \
observations/obs_MSGR_MASCS_UVVS_SURF-MERCURY-140209.json \
observations/obs_MSGR_MASCS_VIRS-MERCURY-140209.json \
observations/obs_MSGR_XRS_MXU-MERCURY-140209.json

#
# All done.
#
exit;
