#!/bin/tcsh

#
# This example script uses the command-line JsonGenerator to make 
# a fairly complete sample set Cosmographia JSON catalog files for  
# the NEAR mission. 
#

#
# First, let's do some prep work: make output directories and 
# observation CSV files.
#
set DESTDIR = `pwd`"/NEAR"

mkdir -p $DESTDIR $DESTDIR/sensors $DESTDIR/observations

set OUTFILE = $DESTDIR/timelist.csv
echo "2001-01-01 05:48:03.043,2001-01-01 05:48:08.643,0"  > $OUTFILE
echo "2001-01-01 05:48:59.650,2001-01-01 05:49:21.650,0" >> $OUTFILE
echo "2001-01-01 05:51:07.661,2001-01-01 05:51:29.661,0" >> $OUTFILE
echo "2001-01-01 05:53:03.069,2001-01-01 05:53:05.669,0" >> $OUTFILE

#
# Now, run JsonGenerator (assuming that it's located under ../bin)
# to generate s/c, sensor, observation, spice data and load catalogs.
# Note that -gencraft's -mp and -genspice's -kr options refer to the
# 3D model and SPICE meta-kernel files not included with or generated 
# by this example script.
#
java -jar ../bin/JsonGenerator.jar \
\
-genmesh \
-of $DESTDIR/body_EROS.json \
-mn NEAR \
-ty asteroid \
-ms 6.69e15 \
-ds 2.67 \
-cn Eros \
-bs 1996-01-02 00:00:00.000 \
-be 2002-08-01 00:00:00.000 \
-cc Sun \
-sc Sun \
-st EROS \
-bf EROS_FIXED \
-mr 0 0 0 1 \
-sz 17.0 \
-mp models/near-a-msi-5-erosshape-v1_0_64q.cmod \
-lc 1 0.5 1 \
-tc 1 0.5 1 \
-dr 1.76 \
-fd 0.1 \
\
-gencraft \
-of $DESTDIR/spacecraft_NEAR.json \
-mn NEAR \
-cn NEAR \
-bs 1996-05-31 01:00:00.000 2000-02-01 00:00:00.000 \
-be 2000-02-01 00:00:00.000 2002-08-01 00:00:00.000 \
-cc Sun                     Eros \
-sc Sun                     Eros \
-st NEAR \
-bf NEAR_SC_BUS_PRIME \
-mr 0.38268343 0.0 0.0 0.92387953 \
-sz 0.003 \
-mp models/near.cmod \
-lc 0.6 1 1 \
-tc 0.6 1 1 \
-dr 0.1 \
-fd 0.5 \
\
-geninst \
-of $DESTDIR/sensors/sensor_NEAR_GRS-EROS.json \
-sn NEAR_GRS \
-si -93004 \
-ct Eros \
-rg 500 \
-rt \
-fc 0 1 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_NEAR.json \
\
-genobs \
-of $DESTDIR/observations/obs_NEAR_GRS-EROS-010101.json \
-on NEAR_GRS_OBS \
-op 0.5 \
-td 10 \
-pc 0 1 1 \
-sv 1.75 \
-ip $DESTDIR/sensors/sensor_NEAR_GRS-EROS.json \
-tp $DESTDIR/timelist.csv \
\
-geninst \
-of $DESTDIR/sensors/sensor_NEAR_MSI-EROS.json \
-sn NEAR_MSI \
-si -93001 \
-ct Eros \
-rg 500 \
-rt \
-fc 1 0 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_NEAR.json \
\
-genobs \
-of $DESTDIR/observations/obs_NEAR_MSI-EROS-010101.json \
-on NEAR_MSI_OBS \
-op 0.5 \
-td 10 \
-pc 1 0 1 \
-sv 1.75 \
-ip $DESTDIR/sensors/sensor_NEAR_MSI-EROS.json \
-tp $DESTDIR/timelist.csv \
\
-geninst \
-of $DESTDIR/sensors/sensor_NEAR_NLR-EROS.json \
-sn NEAR_NLR \
-si -93006 \
-ct Eros \
-rg 500 \
-rt \
-fc 1 1 0 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_NEAR.json \
\
-genobs \
-of $DESTDIR/observations/obs_NEAR_NLR-EROS-010101.json \
-on NEAR_NLR_OBS \
-op 0.5 \
-td 10 \
-pc 1 1 0 \
-sv 1.75 \
-ip $DESTDIR/sensors/sensor_NEAR_NLR-EROS.json \
-tp $DESTDIR/timelist.csv \
\
-geninst \
-of $DESTDIR/sensors/sensor_NEAR_NIS_RECT-EROS.json \
-sn NEAR_NIS_RECT \
-si -93023 \
-ct Eros \
-rg 500 \
-rt \
-fc 0 0.4 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_NEAR.json \
\
-genobs \
-of $DESTDIR/observations/obs_NEAR_NIS_RECT-EROS-010101.json \
-on NEAR_NIS_RECT_OBS \
-op 0.5 \
-td 10 \
-pc 0 0.4 1 \
-sv 1.75 \
-ip $DESTDIR/sensors/sensor_NEAR_NIS_RECT-EROS.json \
-tp $DESTDIR/timelist.csv \
\
-geninst \
-of $DESTDIR/sensors/sensor_NEAR_NIS_SQUA-EROS.json \
-sn NEAR_NIS_SQUA \
-si -93024 \
-ct Eros \
-rg 500 \
-rt \
-fc 0 0.6 1 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_NEAR.json \
\
-genobs \
-of $DESTDIR/observations/obs_NEAR_NIS_SQUA-EROS-010101.json \
-on NEAR_NIS_SQUA_OBS \
-op 0.5 \
-td 10 \
-pc 0 0.6 1 \
-sv 1.75 \
-ip $DESTDIR/sensors/sensor_NEAR_NIS_SQUA-EROS.json \
-tp $DESTDIR/timelist.csv \
\
-geninst \
-of $DESTDIR/sensors/sensor_NEAR_XRS-EROS.json \
-sn NEAR_XRS \
-si -93003 \
-ct Eros \
-rg 500 \
-rt \
-fc 1 0 0 \
-fo 0.3 \
-go 1 \
-fpo 0.8 \
-sd 30 \
-sp $DESTDIR/spacecraft_NEAR.json \
\
-genobs \
-of $DESTDIR/observations/obs_NEAR_XRS-EROS-010101.json \
-on NEAR_XRS_OBS \
-op 0.5 \
-td 10 \
-pc 1 0 0 \
-sv 1.75 \
-ip $DESTDIR/sensors/sensor_NEAR_XRS-EROS.json \
-tp $DESTDIR/timelist.csv \
\
-genspice \
-of $DESTDIR/spice_NEAR.json \
-kr near_v01.tm \
-kp kernels \
\
-genload \
-of $DESTDIR/load_NEAR.json \
-ln \
spice_NEAR.json \
body_EROS.json \
spacecraft_NEAR.json \
sensors/sensor_NEAR_GRS-EROS.json \
sensors/sensor_NEAR_MSI-EROS.json \
sensors/sensor_NEAR_NIS_RECT-EROS.json \
sensors/sensor_NEAR_NIS_SQUA-EROS.json \
sensors/sensor_NEAR_NLR-EROS.json \
sensors/sensor_NEAR_XRS-EROS.json \
observations/obs_NEAR_GRS-EROS-010101.json \
observations/obs_NEAR_MSI-EROS-010101.json \
observations/obs_NEAR_NIS_RECT-EROS-010101.json \
observations/obs_NEAR_NIS_SQUA-EROS-010101.json \
observations/obs_NEAR_NLR-EROS-010101.json \
observations/obs_NEAR_XRS-EROS-010101.json

exit;
